# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Vpsa.api_client import ApiClient


class UsersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_user(self, add_user, **kwargs):  # noqa: E501
        """add_user  # noqa: E501

        Adds a new user.  Available to the primary user only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_user(add_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddUser add_user: (required)
        :return: InlineResponse200211
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_user_with_http_info(add_user, **kwargs)  # noqa: E501
        else:
            (data) = self.add_user_with_http_info(add_user, **kwargs)  # noqa: E501
            return data

    def add_user_with_http_info(self, add_user, **kwargs):  # noqa: E501
        """add_user  # noqa: E501

        Adds a new user.  Available to the primary user only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_user_with_http_info(add_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddUser add_user: (required)
        :return: InlineResponse200211
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['add_user']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'add_user' is set
        if self.api_client.client_side_validation and ('add_user' not in params or
                                                       params['add_user'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `add_user` when calling `add_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_user' in params:
            body_params = params['add_user']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200211',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_user_pass(self, change_user_pass, **kwargs):  # noqa: E501
        """change_user_pass  # noqa: E501

        Change a user's password.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_pass(change_user_pass, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ChangeUserPass change_user_pass: (required)
        :return: InlineResponse200216
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_user_pass_with_http_info(change_user_pass, **kwargs)  # noqa: E501
        else:
            (data) = self.change_user_pass_with_http_info(change_user_pass, **kwargs)  # noqa: E501
            return data

    def change_user_pass_with_http_info(self, change_user_pass, **kwargs):  # noqa: E501
        """change_user_pass  # noqa: E501

        Change a user's password.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_pass_with_http_info(change_user_pass, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ChangeUserPass change_user_pass: (required)
        :return: InlineResponse200216
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['change_user_pass']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_user_pass" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'change_user_pass' is set
        if self.api_client.client_side_validation and ('change_user_pass' not in params or
                                                       params['change_user_pass'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `change_user_pass` when calling `change_user_pass`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_user_pass' in params:
            body_params = params['change_user_pass']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/password.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200216',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_user_pass_by_temp_code(self, id, change_user_pass_by_temp_code, **kwargs):  # noqa: E501
        """change_user_pass_by_temp_code  # noqa: E501

        Change a user's password using a temporary password code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_pass_by_temp_code(id, change_user_pass_by_temp_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ChangeUserPassByTempCode change_user_pass_by_temp_code: (required)
        :return: InlineResponse200217
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_user_pass_by_temp_code_with_http_info(id, change_user_pass_by_temp_code, **kwargs)  # noqa: E501
        else:
            (data) = self.change_user_pass_by_temp_code_with_http_info(id, change_user_pass_by_temp_code, **kwargs)  # noqa: E501
            return data

    def change_user_pass_by_temp_code_with_http_info(self, id, change_user_pass_by_temp_code, **kwargs):  # noqa: E501
        """change_user_pass_by_temp_code  # noqa: E501

        Change a user's password using a temporary password code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_pass_by_temp_code_with_http_info(id, change_user_pass_by_temp_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ChangeUserPassByTempCode change_user_pass_by_temp_code: (required)
        :return: InlineResponse200217
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'change_user_pass_by_temp_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_user_pass_by_temp_code" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `change_user_pass_by_temp_code`")  # noqa: E501
        # verify the required parameter 'change_user_pass_by_temp_code' is set
        if self.api_client.client_side_validation and ('change_user_pass_by_temp_code' not in params or
                                                       params['change_user_pass_by_temp_code'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `change_user_pass_by_temp_code` when calling `change_user_pass_by_temp_code`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_user_pass_by_temp_code' in params:
            body_params = params['change_user_pass_by_temp_code']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/{id}/password_code.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200217',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_user(self, username, **kwargs):  # noqa: E501
        """delete_user  # noqa: E501

        Delete a user. Available to the primary user only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user(username, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: (required)
        :return: InlineResponse200213
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_user_with_http_info(username, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_user_with_http_info(username, **kwargs)  # noqa: E501
            return data

    def delete_user_with_http_info(self, username, **kwargs):  # noqa: E501
        """delete_user  # noqa: E501

        Delete a user. Available to the primary user only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_with_http_info(username, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: (required)
        :return: InlineResponse200213
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if self.api_client.client_side_validation and ('username' not in params or
                                                       params['username'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `username` when calling `delete_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'username' in params:
            path_params['username'] = params['username']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/{username}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200213',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def disable_cloud_admin_access(self, **kwargs):  # noqa: E501
        """disable_cloud_admin_access  # noqa: E501

        Disables cloud admin access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_cloud_admin_access(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200220
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.disable_cloud_admin_access_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.disable_cloud_admin_access_with_http_info(**kwargs)  # noqa: E501
            return data

    def disable_cloud_admin_access_with_http_info(self, **kwargs):  # noqa: E501
        """disable_cloud_admin_access  # noqa: E501

        Disables cloud admin access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_cloud_admin_access_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200220
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_cloud_admin_access" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/admin_access/disable.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200220',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def enable_cloud_admin_access(self, **kwargs):  # noqa: E501
        """enable_cloud_admin_access  # noqa: E501

        Enables cloud admin access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_cloud_admin_access(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200219
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.enable_cloud_admin_access_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.enable_cloud_admin_access_with_http_info(**kwargs)  # noqa: E501
            return data

    def enable_cloud_admin_access_with_http_info(self, **kwargs):  # noqa: E501
        """enable_cloud_admin_access  # noqa: E501

        Enables cloud admin access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_cloud_admin_access_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200219
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method enable_cloud_admin_access" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/admin_access/enable.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200219',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pass_requirements(self, **kwargs):  # noqa: E501
        """get_pass_requirements  # noqa: E501

        Get the password requirements settings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pass_requirements(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200222
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pass_requirements_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_pass_requirements_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_pass_requirements_with_http_info(self, **kwargs):  # noqa: E501
        """get_pass_requirements  # noqa: E501

        Get the password requirements settings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pass_requirements_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200222
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pass_requirements" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/password_requirements_settings.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200222',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_details(self, get_user_details, **kwargs):  # noqa: E501
        """get_user_details  # noqa: E501

        Returns a user's details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_details(get_user_details, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetUserDetails get_user_details: (required)
        :return: InlineResponse200215
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_details_with_http_info(get_user_details, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_details_with_http_info(get_user_details, **kwargs)  # noqa: E501
            return data

    def get_user_details_with_http_info(self, get_user_details, **kwargs):  # noqa: E501
        """get_user_details  # noqa: E501

        Returns a user's details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_details_with_http_info(get_user_details, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetUserDetails get_user_details: (required)
        :return: InlineResponse200215
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['get_user_details']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'get_user_details' is set
        if self.api_client.client_side_validation and ('get_user_details' not in params or
                                                       params['get_user_details'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `get_user_details` when calling `get_user_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_user_details' in params:
            body_params = params['get_user_details']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/login.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200215',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def issue_user_temp_code(self, issue_user_temp_code, **kwargs):  # noqa: E501
        """issue_user_temp_code  # noqa: E501

        Issues a temporary password code to reset a user's password.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issue_user_temp_code(issue_user_temp_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IssueUserTempCode issue_user_temp_code: (required)
        :return: InlineResponse200218
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.issue_user_temp_code_with_http_info(issue_user_temp_code, **kwargs)  # noqa: E501
        else:
            (data) = self.issue_user_temp_code_with_http_info(issue_user_temp_code, **kwargs)  # noqa: E501
            return data

    def issue_user_temp_code_with_http_info(self, issue_user_temp_code, **kwargs):  # noqa: E501
        """issue_user_temp_code  # noqa: E501

        Issues a temporary password code to reset a user's password.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issue_user_temp_code_with_http_info(issue_user_temp_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IssueUserTempCode issue_user_temp_code: (required)
        :return: InlineResponse200218
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['issue_user_temp_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issue_user_temp_code" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'issue_user_temp_code' is set
        if self.api_client.client_side_validation and ('issue_user_temp_code' not in params or
                                                       params['issue_user_temp_code'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `issue_user_temp_code` when calling `issue_user_temp_code`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'issue_user_temp_code' in params:
            body_params = params['issue_user_temp_code']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/reset_password.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200218',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_users(self, **kwargs):  # noqa: E501
        """list_users  # noqa: E501

        List all users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200210
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_users_with_http_info(self, **kwargs):  # noqa: E501
        """list_users  # noqa: E501

        List all users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200210
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_users" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `list_users`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200210',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reset_user_access_key(self, username, reset_user_access_key, **kwargs):  # noqa: E501
        """reset_user_access_key  # noqa: E501

        Reset a user's access key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_user_access_key(username, reset_user_access_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: Username or email address. (required)
        :param ResetUserAccessKey reset_user_access_key: (required)
        :return: InlineResponse200214
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reset_user_access_key_with_http_info(username, reset_user_access_key, **kwargs)  # noqa: E501
        else:
            (data) = self.reset_user_access_key_with_http_info(username, reset_user_access_key, **kwargs)  # noqa: E501
            return data

    def reset_user_access_key_with_http_info(self, username, reset_user_access_key, **kwargs):  # noqa: E501
        """reset_user_access_key  # noqa: E501

        Reset a user's access key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_user_access_key_with_http_info(username, reset_user_access_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: Username or email address. (required)
        :param ResetUserAccessKey reset_user_access_key: (required)
        :return: InlineResponse200214
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'reset_user_access_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reset_user_access_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if self.api_client.client_side_validation and ('username' not in params or
                                                       params['username'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `username` when calling `reset_user_access_key`")  # noqa: E501
        # verify the required parameter 'reset_user_access_key' is set
        if self.api_client.client_side_validation and ('reset_user_access_key' not in params or
                                                       params['reset_user_access_key'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `reset_user_access_key` when calling `reset_user_access_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'username' in params:
            path_params['username'] = params['username']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reset_user_access_key' in params:
            body_params = params['reset_user_access_key']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/{username}/access_key.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200214',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user_info(self, username, update_user_info, **kwargs):  # noqa: E501
        """update_user_info  # noqa: E501

        Update a user's info.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_info(username, update_user_info, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: (required)
        :param UpdateUserInfo update_user_info: (required)
        :return: InlineResponse200212
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_info_with_http_info(username, update_user_info, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_info_with_http_info(username, update_user_info, **kwargs)  # noqa: E501
            return data

    def update_user_info_with_http_info(self, username, update_user_info, **kwargs):  # noqa: E501
        """update_user_info  # noqa: E501

        Update a user's info.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_info_with_http_info(username, update_user_info, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: (required)
        :param UpdateUserInfo update_user_info: (required)
        :return: InlineResponse200212
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'update_user_info']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if self.api_client.client_side_validation and ('username' not in params or
                                                       params['username'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `username` when calling `update_user_info`")  # noqa: E501
        # verify the required parameter 'update_user_info' is set
        if self.api_client.client_side_validation and ('update_user_info' not in params or
                                                       params['update_user_info'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_user_info` when calling `update_user_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'username' in params:
            path_params['username'] = params['username']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_user_info' in params:
            body_params = params['update_user_info']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/{username}.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200212',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user_roles(self, username, update_user_roles, **kwargs):  # noqa: E501
        """update_user_roles  # noqa: E501

        Update a user's roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_roles(username, update_user_roles, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: (required)
        :param UpdateUserRoles update_user_roles: (required)
        :return: InlineResponse200221
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_roles_with_http_info(username, update_user_roles, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_roles_with_http_info(username, update_user_roles, **kwargs)  # noqa: E501
            return data

    def update_user_roles_with_http_info(self, username, update_user_roles, **kwargs):  # noqa: E501
        """update_user_roles  # noqa: E501

        Update a user's roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_roles_with_http_info(username, update_user_roles, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: (required)
        :param UpdateUserRoles update_user_roles: (required)
        :return: InlineResponse200221
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'update_user_roles']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_roles" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if self.api_client.client_side_validation and ('username' not in params or
                                                       params['username'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `username` when calling `update_user_roles`")  # noqa: E501
        # verify the required parameter 'update_user_roles' is set
        if self.api_client.client_side_validation and ('update_user_roles' not in params or
                                                       params['update_user_roles'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_user_roles` when calling `update_user_roles`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'username' in params:
            path_params['username'] = params['username']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_user_roles' in params:
            body_params = params['update_user_roles']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/{username}/roles.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200221',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Vpsa.api_client import ApiClient


class NASApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def change_nas_user_smb_password(self, name, change_nas_user_smb_password, **kwargs):  # noqa: E501
        """change_nas_user_smb_password  # noqa: E501

        Add/change/remove SMB password for NAS users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_nas_user_smb_password(name, change_nas_user_smb_password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param ChangeNasUserSmbPassword change_nas_user_smb_password: (required)
        :return: InlineResponse20056
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_nas_user_smb_password_with_http_info(name, change_nas_user_smb_password, **kwargs)  # noqa: E501
        else:
            (data) = self.change_nas_user_smb_password_with_http_info(name, change_nas_user_smb_password, **kwargs)  # noqa: E501
            return data

    def change_nas_user_smb_password_with_http_info(self, name, change_nas_user_smb_password, **kwargs):  # noqa: E501
        """change_nas_user_smb_password  # noqa: E501

        Add/change/remove SMB password for NAS users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_nas_user_smb_password_with_http_info(name, change_nas_user_smb_password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param ChangeNasUserSmbPassword change_nas_user_smb_password: (required)
        :return: InlineResponse20056
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'change_nas_user_smb_password']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_nas_user_smb_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `change_nas_user_smb_password`")  # noqa: E501
        # verify the required parameter 'change_nas_user_smb_password' is set
        if self.api_client.client_side_validation and ('change_nas_user_smb_password' not in params or
                                                       params['change_nas_user_smb_password'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `change_nas_user_smb_password` when calling `change_nas_user_smb_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_nas_user_smb_password' in params:
            body_params = params['change_nas_user_smb_password']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/nas/users/{name}/password.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20056',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_nas_group(self, create_nas_group, **kwargs):  # noqa: E501
        """create_nas_group  # noqa: E501

        Create a NAS group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_nas_group(create_nas_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateNasGroup create_nas_group: (required)
        :return: InlineResponse20058
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_nas_group_with_http_info(create_nas_group, **kwargs)  # noqa: E501
        else:
            (data) = self.create_nas_group_with_http_info(create_nas_group, **kwargs)  # noqa: E501
            return data

    def create_nas_group_with_http_info(self, create_nas_group, **kwargs):  # noqa: E501
        """create_nas_group  # noqa: E501

        Create a NAS group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_nas_group_with_http_info(create_nas_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateNasGroup create_nas_group: (required)
        :return: InlineResponse20058
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_nas_group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_nas_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_nas_group' is set
        if self.api_client.client_side_validation and ('create_nas_group' not in params or
                                                       params['create_nas_group'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_nas_group` when calling `create_nas_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_nas_group' in params:
            body_params = params['create_nas_group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/nas/groups.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20058',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_nas_user(self, create_nas_user, **kwargs):  # noqa: E501
        """create_nas_user  # noqa: E501

        Create a NAS User.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_nas_user(create_nas_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateNasUser create_nas_user: (required)
        :return: InlineResponse20053
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_nas_user_with_http_info(create_nas_user, **kwargs)  # noqa: E501
        else:
            (data) = self.create_nas_user_with_http_info(create_nas_user, **kwargs)  # noqa: E501
            return data

    def create_nas_user_with_http_info(self, create_nas_user, **kwargs):  # noqa: E501
        """create_nas_user  # noqa: E501

        Create a NAS User.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_nas_user_with_http_info(create_nas_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateNasUser create_nas_user: (required)
        :return: InlineResponse20053
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_nas_user']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_nas_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_nas_user' is set
        if self.api_client.client_side_validation and ('create_nas_user' not in params or
                                                       params['create_nas_user'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_nas_user` when calling `create_nas_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_nas_user' in params:
            body_params = params['create_nas_user']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/nas/users.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20053',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_nas_group(self, name, **kwargs):  # noqa: E501
        """delete_nas_group  # noqa: E501

        Delete a NAS Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_nas_group(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20060
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_nas_group_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_nas_group_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def delete_nas_group_with_http_info(self, name, **kwargs):  # noqa: E501
        """delete_nas_group  # noqa: E501

        Delete a NAS Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_nas_group_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20060
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_nas_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `delete_nas_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/nas/groups/{name}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20060',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_nas_user(self, name, **kwargs):  # noqa: E501
        """delete_nas_user  # noqa: E501

        Delete a NAS User.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_nas_user(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20055
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_nas_user_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_nas_user_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def delete_nas_user_with_http_info(self, name, **kwargs):  # noqa: E501
        """delete_nas_user  # noqa: E501

        Delete a NAS User.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_nas_user_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20055
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_nas_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `delete_nas_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/nas/users/{name}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20055',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_active_directory(self, edit_active_directory, **kwargs):  # noqa: E501
        """edit_active_directory  # noqa: E501

        configure an Active Directory Domain. (Not available while Active Directory is disabled)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_active_directory(edit_active_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EditActiveDirectory edit_active_directory: (required)
        :return: InlineResponse20063
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_active_directory_with_http_info(edit_active_directory, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_active_directory_with_http_info(edit_active_directory, **kwargs)  # noqa: E501
            return data

    def edit_active_directory_with_http_info(self, edit_active_directory, **kwargs):  # noqa: E501
        """edit_active_directory  # noqa: E501

        configure an Active Directory Domain. (Not available while Active Directory is disabled)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_active_directory_with_http_info(edit_active_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EditActiveDirectory edit_active_directory: (required)
        :return: InlineResponse20063
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['edit_active_directory']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_active_directory" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'edit_active_directory' is set
        if self.api_client.client_side_validation and ('edit_active_directory' not in params or
                                                       params['edit_active_directory'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `edit_active_directory` when calling `edit_active_directory`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'edit_active_directory' in params:
            body_params = params['edit_active_directory']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/active_directory/edit.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20063',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_active_directory(self, **kwargs):  # noqa: E501
        """get_active_directory  # noqa: E501

        List the current Active Directory configuration.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_directory(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20061
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_active_directory_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_active_directory_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_active_directory_with_http_info(self, **kwargs):  # noqa: E501
        """get_active_directory  # noqa: E501

        List the current Active Directory configuration.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_directory_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20061
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_active_directory" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/active_directory.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20061',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_nas_groups(self, **kwargs):  # noqa: E501
        """get_all_nas_groups  # noqa: E501

        Show NAS Groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_nas_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20057
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_nas_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_nas_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_nas_groups_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_nas_groups  # noqa: E501

        Show NAS Groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_nas_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20057
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_nas_groups" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_all_nas_groups`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/nas/groups.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20057',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_nas_users(self, **kwargs):  # noqa: E501
        """get_all_nas_users  # noqa: E501

        Get all NAS Users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_nas_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20052
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_nas_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_nas_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_nas_users_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_nas_users  # noqa: E501

        Get all NAS Users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_nas_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20052
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_nas_users" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_all_nas_users`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/nas/users.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20052',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_nas_group(self, name, **kwargs):  # noqa: E501
        """get_nas_group  # noqa: E501

        Get the details for a single NAS Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_nas_group(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20059
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_nas_group_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_nas_group_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_nas_group_with_http_info(self, name, **kwargs):  # noqa: E501
        """get_nas_group  # noqa: E501

        Get the details for a single NAS Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_nas_group_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20059
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_nas_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `get_nas_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/nas/groups/{name}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20059',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_nas_user(self, name, **kwargs):  # noqa: E501
        """get_nas_user  # noqa: E501

        Get the details for a single NAS User.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_nas_user(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20054
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_nas_user_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_nas_user_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_nas_user_with_http_info(self, name, **kwargs):  # noqa: E501
        """get_nas_user  # noqa: E501

        Get the details for a single NAS User.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_nas_user_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20054
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_nas_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `get_nas_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/nas/users/{name}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20054',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def join_active_directory(self, join_active_directory, **kwargs):  # noqa: E501
        """join_active_directory  # noqa: E501

        Join an Active Directory Domain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.join_active_directory(join_active_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JoinActiveDirectory join_active_directory: (required)
        :return: InlineResponse20062
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.join_active_directory_with_http_info(join_active_directory, **kwargs)  # noqa: E501
        else:
            (data) = self.join_active_directory_with_http_info(join_active_directory, **kwargs)  # noqa: E501
            return data

    def join_active_directory_with_http_info(self, join_active_directory, **kwargs):  # noqa: E501
        """join_active_directory  # noqa: E501

        Join an Active Directory Domain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.join_active_directory_with_http_info(join_active_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JoinActiveDirectory join_active_directory: (required)
        :return: InlineResponse20062
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['join_active_directory']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method join_active_directory" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'join_active_directory' is set
        if self.api_client.client_side_validation and ('join_active_directory' not in params or
                                                       params['join_active_directory'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `join_active_directory` when calling `join_active_directory`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'join_active_directory' in params:
            body_params = params['join_active_directory']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/active_directory.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20062',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def leave_active_directory(self, leave_active_directory, **kwargs):  # noqa: E501
        """leave_active_directory  # noqa: E501

        Leave/Delete the current Active Directory server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.leave_active_directory(leave_active_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LeaveActiveDirectory leave_active_directory: (required)
        :return: InlineResponse20064
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.leave_active_directory_with_http_info(leave_active_directory, **kwargs)  # noqa: E501
        else:
            (data) = self.leave_active_directory_with_http_info(leave_active_directory, **kwargs)  # noqa: E501
            return data

    def leave_active_directory_with_http_info(self, leave_active_directory, **kwargs):  # noqa: E501
        """leave_active_directory  # noqa: E501

        Leave/Delete the current Active Directory server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.leave_active_directory_with_http_info(leave_active_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LeaveActiveDirectory leave_active_directory: (required)
        :return: InlineResponse20064
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['leave_active_directory']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method leave_active_directory" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'leave_active_directory' is set
        if self.api_client.client_side_validation and ('leave_active_directory' not in params or
                                                       params['leave_active_directory'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `leave_active_directory` when calling `leave_active_directory`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'leave_active_directory' in params:
            body_params = params['leave_active_directory']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/active_directory/reset.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20064',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def restore_active_directory(self, restore_active_directory, **kwargs):  # noqa: E501
        """restore_active_directory  # noqa: E501

        Restore the current Active Directory server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.restore_active_directory(restore_active_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RestoreActiveDirectory restore_active_directory: (required)
        :return: InlineResponse20065
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.restore_active_directory_with_http_info(restore_active_directory, **kwargs)  # noqa: E501
        else:
            (data) = self.restore_active_directory_with_http_info(restore_active_directory, **kwargs)  # noqa: E501
            return data

    def restore_active_directory_with_http_info(self, restore_active_directory, **kwargs):  # noqa: E501
        """restore_active_directory  # noqa: E501

        Restore the current Active Directory server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.restore_active_directory_with_http_info(restore_active_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RestoreActiveDirectory restore_active_directory: (required)
        :return: InlineResponse20065
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['restore_active_directory']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method restore_active_directory" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'restore_active_directory' is set
        if self.api_client.client_side_validation and ('restore_active_directory' not in params or
                                                       params['restore_active_directory'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `restore_active_directory` when calling `restore_active_directory`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'restore_active_directory' in params:
            body_params = params['restore_active_directory']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/active_directory/restore.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20065',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Zios.api_client import ApiClient


class StoragePoliciesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def capacity_over_time(self, id, **kwargs):  # noqa: E501
        """capacity_over_time  # noqa: E501

        Retrieves details of storage policy capacity over time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.capacity_over_time(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The policy name 'name' value as returned by get_all_policies (required)
        :param int interval: The interval between data points, in seconds
        :param str name: The policy display name 'name' value as returned by get_all_policies, for example '2-Way-Protection'
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.capacity_over_time_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.capacity_over_time_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def capacity_over_time_with_http_info(self, id, **kwargs):  # noqa: E501
        """capacity_over_time  # noqa: E501

        Retrieves details of storage policy capacity over time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.capacity_over_time_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The policy name 'name' value as returned by get_all_policies (required)
        :param int interval: The interval between data points, in seconds
        :param str name: The policy display name 'name' value as returned by get_all_policies, for example '2-Way-Protection'
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method capacity_over_time" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `capacity_over_time`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^storage_policy-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `capacity_over_time`, must conform to the pattern `/^storage_policy-[0-9a-f]{8}$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `capacity_over_time`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/policies/{id}/capacity_over_time.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20039',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_drives_from_policy(self, name, delete_drives_from_policy, **kwargs):  # noqa: E501
        """delete_drives_from_policy  # noqa: E501

        Remove drives from storage policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_drives_from_policy(name, delete_drives_from_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param DeleteDrivesFromPolicy delete_drives_from_policy: (required)
        :return: InlineResponse20038
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_drives_from_policy_with_http_info(name, delete_drives_from_policy, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_drives_from_policy_with_http_info(name, delete_drives_from_policy, **kwargs)  # noqa: E501
            return data

    def delete_drives_from_policy_with_http_info(self, name, delete_drives_from_policy, **kwargs):  # noqa: E501
        """delete_drives_from_policy  # noqa: E501

        Remove drives from storage policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_drives_from_policy_with_http_info(name, delete_drives_from_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param DeleteDrivesFromPolicy delete_drives_from_policy: (required)
        :return: InlineResponse20038
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'delete_drives_from_policy']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_drives_from_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `delete_drives_from_policy`")  # noqa: E501
        # verify the required parameter 'delete_drives_from_policy' is set
        if self.api_client.client_side_validation and ('delete_drives_from_policy' not in params or
                                                       params['delete_drives_from_policy'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `delete_drives_from_policy` when calling `delete_drives_from_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_drives_from_policy' in params:
            body_params = params['delete_drives_from_policy']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/policies/{name}/drives.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20038',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_policies(self, **kwargs):  # noqa: E501
        """get_all_policies  # noqa: E501

        Get a list of Storage policies.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_policies(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20034
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_policies_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_policies_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_policies_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_policies  # noqa: E501

        Get a list of Storage policies.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_policies_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20034
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_policies" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_all_policies`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/policies.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20034',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_policy(self, name, **kwargs):  # noqa: E501
        """get_policy  # noqa: E501

        Get one storage policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_policy(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20035
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_policy_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_policy_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_policy_with_http_info(self, name, **kwargs):  # noqa: E501
        """get_policy  # noqa: E501

        Get one storage policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_policy_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20035
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `get_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/policies/{name}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20035',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def iops(self, id, **kwargs):  # noqa: E501
        """iops  # noqa: E501

        Shows IOPs metering of a storage policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.iops(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The policy name 'name' value as returned by get_all_policies. (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :param str service:
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.iops_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.iops_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def iops_with_http_info(self, id, **kwargs):  # noqa: E501
        """iops  # noqa: E501

        Shows IOPs metering of a storage policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.iops_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The policy name 'name' value as returned by get_all_policies. (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :param str service:
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval', 'count', 'service']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method iops" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `iops`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^storage_policy-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `iops`, must conform to the pattern `/^storage_policy-[0-9a-f]{8}$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `iops`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('count' in params and params['count'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `count` when calling `iops`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'service' in params:
            query_params.append(('service', params['service']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/policies/{id}/iops.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20012',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def latency(self, id, **kwargs):  # noqa: E501
        """latency  # noqa: E501

        Shows latency metering (ms) of a storage policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.latency(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The policy name 'name' value as returned by get_all_policies. (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :param str service:
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.latency_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.latency_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def latency_with_http_info(self, id, **kwargs):  # noqa: E501
        """latency  # noqa: E501

        Shows latency metering (ms) of a storage policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.latency_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The policy name 'name' value as returned by get_all_policies. (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :param str service:
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval', 'count', 'service']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method latency" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `latency`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^storage_policy-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `latency`, must conform to the pattern `/^storage_policy-[0-9a-f]{8}$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `latency`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('count' in params and params['count'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `count` when calling `latency`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'service' in params:
            query_params.append(('service', params['service']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/policies/{id}/latency.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20013',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_default_policy(self, name, **kwargs):  # noqa: E501
        """set_default_policy  # noqa: E501

        Set a default storage policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_default_policy(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_default_policy_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.set_default_policy_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def set_default_policy_with_http_info(self, name, **kwargs):  # noqa: E501
        """set_default_policy  # noqa: E501

        Set a default storage policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_default_policy_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_default_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `set_default_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/policies/{name}/set_default.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20037',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def throughput(self, id, **kwargs):  # noqa: E501
        """throughput  # noqa: E501

        Shows bandwidth throughput metering (B/s) of a storage policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.throughput(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The policy name 'name' value as returned by get_all_policies. (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :param str service:
        :return: InlineResponse20014
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.throughput_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.throughput_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def throughput_with_http_info(self, id, **kwargs):  # noqa: E501
        """throughput  # noqa: E501

        Shows bandwidth throughput metering (B/s) of a storage policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.throughput_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The policy name 'name' value as returned by get_all_policies. (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :param str service:
        :return: InlineResponse20014
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval', 'count', 'service']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method throughput" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `throughput`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^storage_policy-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `throughput`, must conform to the pattern `/^storage_policy-[0-9a-f]{8}$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `throughput`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('count' in params and params['count'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `count` when calling `throughput`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'service' in params:
            query_params.append(('service', params['service']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/policies/{id}/throughput.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20014',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_storage_policy(self, name, update_storage_policy, **kwargs):  # noqa: E501
        """update_storage_policy  # noqa: E501

        Update a storage policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_storage_policy(name, update_storage_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param UpdateStoragePolicy update_storage_policy: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_storage_policy_with_http_info(name, update_storage_policy, **kwargs)  # noqa: E501
        else:
            (data) = self.update_storage_policy_with_http_info(name, update_storage_policy, **kwargs)  # noqa: E501
            return data

    def update_storage_policy_with_http_info(self, name, update_storage_policy, **kwargs):  # noqa: E501
        """update_storage_policy  # noqa: E501

        Update a storage policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_storage_policy_with_http_info(name, update_storage_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param UpdateStoragePolicy update_storage_policy: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'update_storage_policy']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_storage_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `update_storage_policy`")  # noqa: E501
        # verify the required parameter 'update_storage_policy' is set
        if self.api_client.client_side_validation and ('update_storage_policy' not in params or
                                                       params['update_storage_policy'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_storage_policy` when calling `update_storage_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_storage_policy' in params:
            body_params = params['update_storage_policy']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/policies/{name}.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20036',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class UpdateRosDestination(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bucket': 'str',
        'endpoint': 'str',
        'username': 'str',
        'password': 'str',
        'connect_via': 'str',
        'proxyhost': 'str',
        'proxyport': 'str',
        'proxyuser': 'str',
        'proxypassword': 'str',
        'use_proxy': 'str'
    }

    attribute_map = {
        'bucket': 'bucket',
        'endpoint': 'endpoint',
        'username': 'username',
        'password': 'password',
        'connect_via': 'connectVia',
        'proxyhost': 'proxyhost',
        'proxyport': 'proxyport',
        'proxyuser': 'proxyuser',
        'proxypassword': 'proxypassword',
        'use_proxy': 'use_proxy'
    }

    def __init__(self, bucket=None, endpoint=None, username=None, password=None, connect_via=None, proxyhost=None, proxyport=None, proxyuser=None, proxypassword=None, use_proxy=None, _configuration=None):  # noqa: E501
        """UpdateRosDestination - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._bucket = None
        self._endpoint = None
        self._username = None
        self._password = None
        self._connect_via = None
        self._proxyhost = None
        self._proxyport = None
        self._proxyuser = None
        self._proxypassword = None
        self._use_proxy = None
        self.discriminator = None

        if bucket is not None:
            self.bucket = bucket
        if endpoint is not None:
            self.endpoint = endpoint
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if connect_via is not None:
            self.connect_via = connect_via
        if proxyhost is not None:
            self.proxyhost = proxyhost
        if proxyport is not None:
            self.proxyport = proxyport
        if proxyuser is not None:
            self.proxyuser = proxyuser
        if proxypassword is not None:
            self.proxypassword = proxypassword
        if use_proxy is not None:
            self.use_proxy = use_proxy

    @property
    def bucket(self):
        """Gets the bucket of this UpdateRosDestination.  # noqa: E501

        remote object storage bucket name / Azure cloud container name  # noqa: E501

        :return: The bucket of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this UpdateRosDestination.

        remote object storage bucket name / Azure cloud container name  # noqa: E501

        :param bucket: The bucket of this UpdateRosDestination.  # noqa: E501
        :type: str
        """

        self._bucket = bucket

    @property
    def endpoint(self):
        """Gets the endpoint of this UpdateRosDestination.  # noqa: E501

        Endpoint for remote object storage (use 'storage.googleapis.com' for Google cloud, use 'blob.core.windows.net' for Azure cloud).  # noqa: E501

        :return: The endpoint of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this UpdateRosDestination.

        Endpoint for remote object storage (use 'storage.googleapis.com' for Google cloud, use 'blob.core.windows.net' for Azure cloud).  # noqa: E501

        :param endpoint: The endpoint of this UpdateRosDestination.  # noqa: E501
        :type: str
        """
        allowed_values = ["s3-eu-west-1.amazonaws.com", "blob.core.windows.net"]  # noqa: E501
        if (self._configuration.client_side_validation and
                endpoint not in allowed_values):
            raise ValueError(
                "Invalid value for `endpoint` ({0}), must be one of {1}"  # noqa: E501
                .format(endpoint, allowed_values)
            )

        self._endpoint = endpoint

    @property
    def username(self):
        """Gets the username of this UpdateRosDestination.  # noqa: E501

        Access Key ID for remote object storage / Account in Azure cloud.  # noqa: E501

        :return: The username of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this UpdateRosDestination.

        Access Key ID for remote object storage / Account in Azure cloud.  # noqa: E501

        :param username: The username of this UpdateRosDestination.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def password(self):
        """Gets the password of this UpdateRosDestination.  # noqa: E501

        Secret Access Key for remote object storage / Storage account key in Azure cloud.  # noqa: E501

        :return: The password of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UpdateRosDestination.

        Secret Access Key for remote object storage / Storage account key in Azure cloud.  # noqa: E501

        :param password: The password of this UpdateRosDestination.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def connect_via(self):
        """Gets the connect_via of this UpdateRosDestination.  # noqa: E501

        Connection method for remote object storage / Azure cloud  # noqa: E501

        :return: The connect_via of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._connect_via

    @connect_via.setter
    def connect_via(self, connect_via):
        """Sets the connect_via of this UpdateRosDestination.

        Connection method for remote object storage / Azure cloud  # noqa: E501

        :param connect_via: The connect_via of this UpdateRosDestination.  # noqa: E501
        :type: str
        """
        allowed_values = ["fe", "public"]  # noqa: E501
        if (self._configuration.client_side_validation and
                connect_via not in allowed_values):
            raise ValueError(
                "Invalid value for `connect_via` ({0}), must be one of {1}"  # noqa: E501
                .format(connect_via, allowed_values)
            )

        self._connect_via = connect_via

    @property
    def proxyhost(self):
        """Gets the proxyhost of this UpdateRosDestination.  # noqa: E501

        Proxy host  # noqa: E501

        :return: The proxyhost of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxyhost

    @proxyhost.setter
    def proxyhost(self, proxyhost):
        """Sets the proxyhost of this UpdateRosDestination.

        Proxy host  # noqa: E501

        :param proxyhost: The proxyhost of this UpdateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxyhost = proxyhost

    @property
    def proxyport(self):
        """Gets the proxyport of this UpdateRosDestination.  # noqa: E501

        Port for proxy  # noqa: E501

        :return: The proxyport of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxyport

    @proxyport.setter
    def proxyport(self, proxyport):
        """Sets the proxyport of this UpdateRosDestination.

        Port for proxy  # noqa: E501

        :param proxyport: The proxyport of this UpdateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxyport = proxyport

    @property
    def proxyuser(self):
        """Gets the proxyuser of this UpdateRosDestination.  # noqa: E501

        Username for proxy  # noqa: E501

        :return: The proxyuser of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxyuser

    @proxyuser.setter
    def proxyuser(self, proxyuser):
        """Sets the proxyuser of this UpdateRosDestination.

        Username for proxy  # noqa: E501

        :param proxyuser: The proxyuser of this UpdateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxyuser = proxyuser

    @property
    def proxypassword(self):
        """Gets the proxypassword of this UpdateRosDestination.  # noqa: E501

        Password for proxy  # noqa: E501

        :return: The proxypassword of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxypassword

    @proxypassword.setter
    def proxypassword(self, proxypassword):
        """Sets the proxypassword of this UpdateRosDestination.

        Password for proxy  # noqa: E501

        :param proxypassword: The proxypassword of this UpdateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxypassword = proxypassword

    @property
    def use_proxy(self):
        """Gets the use_proxy of this UpdateRosDestination.  # noqa: E501


        :return: The use_proxy of this UpdateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._use_proxy

    @use_proxy.setter
    def use_proxy(self, use_proxy):
        """Sets the use_proxy of this UpdateRosDestination.


        :param use_proxy: The use_proxy of this UpdateRosDestination.  # noqa: E501
        :type: str
        """

        self._use_proxy = use_proxy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateRosDestination, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateRosDestination):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateRosDestination):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse2008CloudUser(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'username': 'str',
        'tenant': 'str',
        'tenant_internal_id': 'int',
        'custom_network': 'str',
        'vlan_id': 'int'
    }

    attribute_map = {
        'username': 'username',
        'tenant': 'tenant',
        'tenant_internal_id': 'tenant_internal_id',
        'custom_network': 'custom_network',
        'vlan_id': 'vlan_id'
    }

    def __init__(self, username=None, tenant=None, tenant_internal_id=None, custom_network=None, vlan_id=None, _configuration=None):  # noqa: E501
        """InlineResponse2008CloudUser - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._username = None
        self._tenant = None
        self._tenant_internal_id = None
        self._custom_network = None
        self._vlan_id = None
        self.discriminator = None

        if username is not None:
            self.username = username
        if tenant is not None:
            self.tenant = tenant
        if tenant_internal_id is not None:
            self.tenant_internal_id = tenant_internal_id
        if custom_network is not None:
            self.custom_network = custom_network
        if vlan_id is not None:
            self.vlan_id = vlan_id

    @property
    def username(self):
        """Gets the username of this InlineResponse2008CloudUser.  # noqa: E501


        :return: The username of this InlineResponse2008CloudUser.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this InlineResponse2008CloudUser.


        :param username: The username of this InlineResponse2008CloudUser.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def tenant(self):
        """Gets the tenant of this InlineResponse2008CloudUser.  # noqa: E501


        :return: The tenant of this InlineResponse2008CloudUser.  # noqa: E501
        :rtype: str
        """
        return self._tenant

    @tenant.setter
    def tenant(self, tenant):
        """Sets the tenant of this InlineResponse2008CloudUser.


        :param tenant: The tenant of this InlineResponse2008CloudUser.  # noqa: E501
        :type: str
        """

        self._tenant = tenant

    @property
    def tenant_internal_id(self):
        """Gets the tenant_internal_id of this InlineResponse2008CloudUser.  # noqa: E501


        :return: The tenant_internal_id of this InlineResponse2008CloudUser.  # noqa: E501
        :rtype: int
        """
        return self._tenant_internal_id

    @tenant_internal_id.setter
    def tenant_internal_id(self, tenant_internal_id):
        """Sets the tenant_internal_id of this InlineResponse2008CloudUser.


        :param tenant_internal_id: The tenant_internal_id of this InlineResponse2008CloudUser.  # noqa: E501
        :type: int
        """

        self._tenant_internal_id = tenant_internal_id

    @property
    def custom_network(self):
        """Gets the custom_network of this InlineResponse2008CloudUser.  # noqa: E501


        :return: The custom_network of this InlineResponse2008CloudUser.  # noqa: E501
        :rtype: str
        """
        return self._custom_network

    @custom_network.setter
    def custom_network(self, custom_network):
        """Sets the custom_network of this InlineResponse2008CloudUser.


        :param custom_network: The custom_network of this InlineResponse2008CloudUser.  # noqa: E501
        :type: str
        """

        self._custom_network = custom_network

    @property
    def vlan_id(self):
        """Gets the vlan_id of this InlineResponse2008CloudUser.  # noqa: E501


        :return: The vlan_id of this InlineResponse2008CloudUser.  # noqa: E501
        :rtype: int
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """Sets the vlan_id of this InlineResponse2008CloudUser.


        :param vlan_id: The vlan_id of this InlineResponse2008CloudUser.  # noqa: E501
        :type: int
        """

        self._vlan_id = vlan_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2008CloudUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2008CloudUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2008CloudUser):
            return True

        return self.to_dict() != other.to_dict()
